#
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker

plt.rcParams["font.family"] = "Ubuntu"

#Extraction des données

table= pd.read_csv("EdTimcce.csv", delimiter='\t')

angle=table["rang"]*360/365
edt=table["edt"]

#Tracé et réglages globaux du graphique :
fig=plt.figure(figsize=(8,8))
ax=fig.add_subplot(111, projection='polar')
plt.title('Équation du temps (min)', fontsize=25)

ax.grid(which='major', color='dimgray')
ax.grid(which='minor', color='lightgray')

plt.plot(np.radians(angle), edt, lw='2')

theta =np.arange(0, 2*np.pi, 0.01)
zero=theta*0
plt.plot(theta, zero)

#Zones de couleurs :
zero=angle*0
min=np.minimum(edt, zero)
max=np.maximum(edt, zero)
plt.fill_between(np.radians(angle), min,edt,facecolor='greenyellow', alpha=0.2)
plt.fill_between(np.radians(angle), edt,max, facecolor='darkorange', alpha=0.2)


#------Reglages en x (angles) :---------------------------------------

dates=np.radians([1, 32, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335])#coordonnées du 1er jour du mois
initiale=["J", "F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D"]#initiale du mois
ax.xaxis.set_ticks(dates)
ax.xaxis.set_ticklabels(initiale, fontsize=12)
#On aurait aussi pu faire :
#plt.xticks(dates, initiale)

dixjours=[]#création d'une liste pour les graduations secondaires aux jours 10 et 20 du mois
for i in range(len(dates)):
    dixjours.append(dates[i]+np.radians(9))
    dixjours.append(dates[i]+np.radians(19))

ax.set_xticks(dixjours, minor=True)

#------Reglages en y (minutes) :---------------------------------------
ax.yaxis.set_minor_locator(ticker.MultipleLocator(1))#espace pour grille secondaire y
ax.set_ylim(-17, 15)
ax.set_rlabel_position(0)

plt.yticks(fontsize=8, ha='center')

plt.text(np.radians(-90), 13, "Données IMCCE 2021", backgroundcolor='white', ha='center')
fig.savefig('equationDuTempsVolvelle.png', transparent=False, dpi=200)# Création image PNG 
plt.show()
